@@ -25,6 +25,8 @@
  *
  * #GDataAuthor represents a "author" element from the
  * <ulink type="http" url="http://www.atomenabled.org/developers/syndication/atom-format-spec.php">Atom specification</ulink>.
+ *
+ * Since: 0.4.0
  **/
 
 #include <glib.h>
@@ -190,34 +192,37 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 {
 	GDataAuthorPrivate *priv = GDATA_AUTHOR (parsable)->priv;
 
-	if (xmlStrcmp (node->name, (xmlChar*) "name") == 0) {
-		/* atom:name */
-		xmlChar *name;
+	if (gdata_parser_is_namespace (node, "http://www.w3.org/2005/Atom") == TRUE) {
+		if (xmlStrcmp (node->name, (xmlChar*) "name") == 0) {
+			/* atom:name */
+			xmlChar *name;
 
-		if (priv->name != NULL)
-			return gdata_parser_error_duplicate_element (node, error);
+			if (priv->name != NULL)
+				return gdata_parser_error_duplicate_element (node, error);
 
-		name = xmlNodeListGetString (doc, node->children, TRUE);
-		if (name == NULL || *name == '\0') {
-			xmlFree (name);
-			return gdata_parser_error_required_content_missing (node, error);
+			name = xmlNodeListGetString (doc, node->children, TRUE);
+			if (name == NULL || *name == '\0') {
+				xmlFree (name);
+				return gdata_parser_error_required_content_missing (node, error);
+			}
+			priv->name = (gchar*) name;
+		} else if (xmlStrcmp (node->name, (xmlChar*) "uri") == 0) {
+			/* atom:uri */
+			if (priv->uri != NULL)
+				return gdata_parser_error_duplicate_element (node, error);
+
+			priv->uri = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
+		} else if (xmlStrcmp (node->name, (xmlChar*) "email") == 0) {
+			/* atom:email */
+			if (priv->email_address != NULL)
+				return gdata_parser_error_duplicate_element (node, error);
+
+			priv->email_address = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
+		} else {
+			return GDATA_PARSABLE_CLASS (gdata_author_parent_class)->parse_xml (parsable, doc, node, user_data, error);
 		}
-		priv->name = (gchar*) name;
-	} else if (xmlStrcmp (node->name, (xmlChar*) "uri") == 0) {
-		/* atom:uri */
-		if (priv->uri != NULL)
-			return gdata_parser_error_duplicate_element (node, error);
-
-		priv->uri = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
-	} else if (xmlStrcmp (node->name, (xmlChar*) "email") == 0) {
-		/* atom:email */
-		if (priv->email_address != NULL)
-			return gdata_parser_error_duplicate_element (node, error);
-
-		priv->email_address = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
-	} else if (GDATA_PARSABLE_CLASS (gdata_author_parent_class)->parse_xml (parsable, doc, node, user_data, error) == FALSE) {
-		/* Error! */
-		return FALSE;
+	} else {
+		return GDATA_PARSABLE_CLASS (gdata_author_parent_class)->parse_xml (parsable, doc, node, user_data, error);
 	}
 
 	return TRUE;
@@ -251,8 +256,8 @@ get_xml (GDataParsable *parsable, GString *xml_string)
 /**
  * gdata_author_new:
  * @name: the author's name
- * @uri: an IRI describing the author, or %NULL
- * @email_address: the author's e-mail address, or %NULL
+ * @uri: (allow-none): an IRI describing the author, or %NULL
+ * @email_address: (allow-none): the author's e-mail address, or %NULL
  *
  * Creates a new #GDataAuthor. More information is available in the <ulink type="http"
  * url="http://www.atomenabled.org/developers/syndication/atom-format-spec.php#element.author">Atom specification</ulink>.
@@ -272,11 +277,13 @@ gdata_author_new (const gchar *name, const gchar *uri, const gchar *email_addres
  * @b: another #GDataAuthor, or %NULL
  *
  * Compares the two authors in a strcmp() fashion. %NULL values are handled gracefully, with
- * %0 returned if both @a and @b are %NULL, %-1 if @a is %NULL and %1 if @b is %NULL.
+ * <code class="literal">0</code> returned if both @a and @b are %NULL, <code class="literal">-1</code> if @a is %NULL
+ * and <code class="literal">1</code> if @b is %NULL.
  *
  * The comparison of non-%NULL values is done on the basis of the @name property of the #GDataAuthor<!-- -->s.
  *
- * Return value: %0 if @a equals @b, %-1 or %1 as appropriate otherwise
+ * Return value: <code class="literal">0</code> if @a equals @b, <code class="literal">-1</code> or <code class="literal">1</code> as
+ * appropriate otherwise
  *
  * Since: 0.4.0
  **/
@@ -350,7 +357,7 @@ gdata_author_get_uri (GDataAuthor *self)
 /**
  * gdata_author_set_uri:
  * @self: a #GDataAuthor
- * @uri: the new URI for the author, or %NULL
+ * @uri: (allow-none): the new URI for the author, or %NULL
  *
  * Sets the #GDataAuthor:uri property to @uri.
  *
@@ -388,7 +395,7 @@ gdata_author_get_email_address (GDataAuthor *self)
 /**
  * gdata_author_set_email_address:
  * @self: a #GDataAuthor
- * @email_address: the new e-mail address for the author, or %NULL
+ * @email_address: (allow-none): the new e-mail address for the author, or %NULL
  *
  * Sets the #GDataAuthor:email-address property to @email_address.
  *
