@@ -25,6 +25,8 @@
  *
  * #GDataGDOrganization represents an "organization" element from the
  * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdOrganization">GData specification</ulink>.
+ *
+ * Since: 0.4.0
  **/
 
 #include <glib.h>
@@ -394,6 +396,9 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 {
 	GDataGDOrganizationPrivate *priv = GDATA_GD_ORGANIZATION (parsable)->priv;
 
+	if (gdata_parser_is_namespace (node, "http://schemas.google.com/g/2005") == FALSE)
+		return GDATA_PARSABLE_CLASS (gdata_gd_organization_parent_class)->parse_xml (parsable, doc, node, user_data, error);
+
 	if (xmlStrcmp (node->name, (xmlChar*) "orgName") == 0) {
 		/* gd:orgName */
 		if (priv->name != NULL)
@@ -431,9 +436,8 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 		}
 
 		priv->location = location;
-	} else if (GDATA_PARSABLE_CLASS (gdata_gd_organization_parent_class)->parse_xml (parsable, doc, node, user_data, error) == FALSE) {
-		/* Error! */
-		return FALSE;
+	} else {
+		return GDATA_PARSABLE_CLASS (gdata_gd_organization_parent_class)->parse_xml (parsable, doc, node, user_data, error);
 	}
 
 	return TRUE;
@@ -482,10 +486,10 @@ get_namespaces (GDataParsable *parsable, GHashTable *namespaces)
 
 /**
  * gdata_gd_organization_new:
- * @name: the name of the organization, or %NULL
- * @title: the owner's title within the organization, or %NULL
- * @relation_type: the relationship between the organization and its owner, or %NULL
- * @label: a human-readable label for the organization, or %NULL
+ * @name: (allow-none): the name of the organization, or %NULL
+ * @title: (allow-none): the owner's title within the organization, or %NULL
+ * @relation_type: (allow-none): the relationship between the organization and its owner, or %NULL
+ * @label: (allow-none): a human-readable label for the organization, or %NULL
  * @is_primary: %TRUE if this organization is its owner's primary organization, %FALSE otherwise
  *
  * Creates a new #GDataGDOrganization. More information is available in the <ulink type="http"
@@ -509,11 +513,13 @@ gdata_gd_organization_new (const gchar *name, const gchar *title, const gchar *r
  * @b: another #GDataGDOrganization, or %NULL
  *
  * Compares the two organizations in a strcmp() fashion. %NULL values are handled gracefully, with
- * %0 returned if both @a and @b are %NULL, %-1 if @a is %NULL and %1 if @b is %NULL.
+ * <code class="literal">0</code> returned if both @a and @b are %NULL, <code class="literal">-1</code> if @a is %NULL
+ * and <code class="literal">1</code> if @b is %NULL.
  *
  * The comparison of non-%NULL values is done on the basis of the @name property of the #GDataGDOrganization<!-- -->s.
  *
- * Return value: %0 if @a equals @b, %-1 or %1 as appropriate otherwise
+ * Return value: <code class="literal">0</code> if @a equals @b, <code class="literal">-1</code> or <code class="literal">1</code> as
+ * appropriate otherwise
  *
  * Since: 0.4.0
  **/
@@ -522,7 +528,7 @@ gdata_gd_organization_compare (const GDataGDOrganization *a, const GDataGDOrgani
 {
 	if (a == NULL && b != NULL)
 		return -1;
-	else if (b == NULL)
+	else if (a != NULL && b == NULL)
 		return 1;
 
 	if (a == b)
@@ -553,7 +559,7 @@ gdata_gd_organization_get_name (GDataGDOrganization *self)
 /**
  * gdata_gd_organization_set_name:
  * @self: a #GDataGDOrganization
- * @name: the new name for the organization
+ * @name: (allow-none): the new name for the organization, or %NULL
  *
  * Sets the #GDataGDOrganization:name property to @name.
  *
@@ -591,7 +597,7 @@ gdata_gd_organization_get_title (GDataGDOrganization *self)
 /**
  * gdata_gd_organization_set_title:
  * @self: a #GDataGDOrganization
- * @title: the new title for the organization, or %NULL
+ * @title: (allow-none): the new title for the organization, or %NULL
  *
  * Sets the #GDataGDOrganization:title property to @title.
  *
@@ -629,7 +635,7 @@ gdata_gd_organization_get_relation_type (GDataGDOrganization *self)
 /**
  * gdata_gd_organization_set_relation_type:
  * @self: a #GDataGDOrganization
- * @relation_type: the new relation type for the organization, or %NULL
+ * @relation_type: (allow-none): the new relation type for the organization, or %NULL
  *
  * Sets the #GDataGDOrganization:relation-type property to @relation_type.
  *
@@ -668,7 +674,7 @@ gdata_gd_organization_get_label (GDataGDOrganization *self)
 /**
  * gdata_gd_organization_set_label:
  * @self: a #GDataGDOrganization
- * @label: the new label for the organization, or %NULL
+ * @label: (allow-none): the new label for the organization, or %NULL
  *
  * Sets the #GDataGDOrganization:label property to @label.
  *
@@ -741,7 +747,7 @@ gdata_gd_organization_get_department (GDataGDOrganization *self)
 /**
  * gdata_gd_organization_set_department:
  * @self: a #GDataGDOrganization
- * @department: the new department for the person working in the organization
+ * @department: (allow-none): the new department for the person working in the organization, or %NULL
  *
  * Sets the #GDataGDOrganization:department property to @department.
  *
@@ -779,7 +785,7 @@ gdata_gd_organization_get_job_description (GDataGDOrganization *self)
 /**
  * gdata_gd_organization_set_job_description:
  * @self: a #GDataGDOrganization
- * @job_description: the new job description for the person in the organization
+ * @job_description: (allow-none): the new job description for the person in the organization, or %NULL
  *
  * Sets the #GDataGDOrganization:job-description property to @job_description.
  *
@@ -817,7 +823,7 @@ gdata_gd_organization_get_symbol (GDataGDOrganization *self)
 /**
  * gdata_gd_organization_set_symbol:
  * @self: a #GDataGDOrganization
- * @symbol: the new stock symbol for the organization
+ * @symbol: (allow-none): the new stock symbol for the organization, or %NULL
  *
  * Sets the #GDataGDOrganization:symbol property to @symbol.
  *
@@ -841,7 +847,7 @@ gdata_gd_organization_set_symbol (GDataGDOrganization *self, const gchar *symbol
  *
  * Gets the #GDataGDOrganization:location property.
  *
- * Return value: the organization's location, or %NULL
+ * Return value: (transfer none): the organization's location, or %NULL
  *
  * Since: 0.6.0
  **/
@@ -855,7 +861,7 @@ gdata_gd_organization_get_location (GDataGDOrganization *self)
 /**
  * gdata_gd_organization_set_location:
  * @self: a #GDataGDOrganization
- * @location: the new location for the organization, or %NULL
+ * @location: (allow-none): the new location for the organization, or %NULL
  *
  * Sets the #GDataGDOrganization:location property to @location.
  *
