@@ -25,6 +25,8 @@
  *
  * #GDataGDPhoneNumber represents a "phoneNumber" element from the
  * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber">GData specification</ulink>.
+ *
+ * Since: 0.4.0
  **/
 
 #include <glib.h>
@@ -334,9 +336,9 @@ get_namespaces (GDataParsable *parsable, GHashTable *namespaces)
 /**
  * gdata_gd_phone_number_new:
  * @number: the phone number, in human-readable format
- * @relation_type: the relationship between the phone number and its owner, or %NULL
- * @label: a human-readable label for the phone number, or %NULL
- * @uri: a "tel URI" to represent the number formally (see
+ * @relation_type: (allow-none): the relationship between the phone number and its owner, or %NULL
+ * @label: (allow-none): a human-readable label for the phone number, or %NULL
+ * @uri: (allow-none): a "tel URI" to represent the number formally (see
  * <ulink type="http" url="http://www.ietf.org/rfc/rfc3966.txt">RFC 3966</ulink>), or %NULL
  * @is_primary: %TRUE if this phone number is its owner's primary number, %FALSE otherwise
  *
@@ -361,11 +363,13 @@ gdata_gd_phone_number_new (const gchar *number, const gchar *relation_type, cons
  * @b: another #GDataGDPhoneNumber, or %NULL
  *
  * Compares the two phone numbers in a strcmp() fashion. %NULL values are handled gracefully, with
- * %0 returned if both @a and @b are %NULL, %-1 if @a is %NULL and %1 if @b is %NULL.
+ * <code class="literal">0</code> returned if both @a and @b are %NULL, <code class="literal">-1</code> if @a is %NULL
+ * and <code class="literal">1</code> if @b is %NULL.
  *
  * The comparison of non-%NULL values is done on the basis of the @number property of the #GDataGDPhoneNumber<!-- -->s.
  *
- * Return value: %0 if @a equals @b, %-1 or %1 as appropriate otherwise
+ * Return value: <code class="literal">0</code> if @a equals @b, <code class="literal">-1</code> or <code class="literal">1</code> as
+ * appropriate otherwise
  *
  * Since: 0.4.0
  **/
@@ -374,7 +378,7 @@ gdata_gd_phone_number_compare (const GDataGDPhoneNumber *a, const GDataGDPhoneNu
 {
 	if (a == NULL && b != NULL)
 		return -1;
-	else if (b == NULL)
+	else if (a != NULL && b == NULL)
 		return 1;
 
 	if (a == b)
@@ -441,7 +445,7 @@ gdata_gd_phone_number_get_uri (GDataGDPhoneNumber *self)
 /**
  * gdata_gd_phone_number_set_uri:
  * @self: a #GDataGDPhoneNumber
- * @uri: the new URI for the phone number, or %NULL
+ * @uri: (allow-none): the new URI for the phone number, or %NULL
  *
  * Sets the #GDataGDPhoneNumber:uri property to @uri.
  *
@@ -479,7 +483,7 @@ gdata_gd_phone_number_get_relation_type (GDataGDPhoneNumber *self)
 /**
  * gdata_gd_phone_number_set_relation_type:
  * @self: a #GDataGDPhoneNumber
- * @relation_type: the new relation type for the phone number, or %NULL
+ * @relation_type: (allow-none): the new relation type for the phone number, or %NULL
  *
  * Sets the #GDataGDPhoneNumber:relation-type property to @relation_type.
  *
@@ -518,7 +522,7 @@ gdata_gd_phone_number_get_label (GDataGDPhoneNumber *self)
 /**
  * gdata_gd_phone_number_set_label:
  * @self: a #GDataGDPhoneNumber
- * @label: the new label for the phone number, or %NULL
+ * @label: (allow-none): the new label for the phone number, or %NULL
  *
  * Sets the #GDataGDPhoneNumber:label property to @label.
  *
