@@ -26,6 +26,8 @@
  * #GDataGDPostalAddress represents a "structuredPostalAddress" element from the
  * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdStructuredPostalAddress">GData specification</ulink>.
  * Note that it does not represent a simple "postalAddress" element, as "structuredPostalAddress" is now used wherever possible in the GData API.
+ *
+ * Since: 0.4.0
  **/
 
 #include <glib.h>
@@ -587,20 +589,21 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 {
 	GDataGDPostalAddressPrivate *priv = GDATA_GD_POSTAL_ADDRESS (parsable)->priv;
 
-	PARSE_STRING_ELEMENT ("agent", agent)
-	else PARSE_STRING_ELEMENT ("housename", house_name)
-	else PARSE_STRING_ELEMENT ("pobox", po_box)
-	else PARSE_STRING_ELEMENT ("street", street)
-	else PARSE_STRING_ELEMENT ("neighborhood", neighborhood)
-	else PARSE_STRING_ELEMENT ("city", city)
-	else PARSE_STRING_ELEMENT ("subregion", subregion)
-	else PARSE_STRING_ELEMENT ("region", region)
-	else PARSE_STRING_ELEMENT ("postcode", postcode)
-	else PARSE_STRING_ELEMENT ("country", country)
-	else PARSE_STRING_ELEMENT ("formattedAddress", formatted_address)
-	else if (GDATA_PARSABLE_CLASS (gdata_gd_postal_address_parent_class)->parse_xml (parsable, doc, node, user_data, error) == FALSE) {
-		/* Error! */
-		return FALSE;
+	if (gdata_parser_is_namespace (node, "http://schemas.google.com/g/2005") == TRUE) {
+		PARSE_STRING_ELEMENT ("agent", agent)
+		else PARSE_STRING_ELEMENT ("housename", house_name)
+		else PARSE_STRING_ELEMENT ("pobox", po_box)
+		else PARSE_STRING_ELEMENT ("street", street)
+		else PARSE_STRING_ELEMENT ("neighborhood", neighborhood)
+		else PARSE_STRING_ELEMENT ("city", city)
+		else PARSE_STRING_ELEMENT ("subregion", subregion)
+		else PARSE_STRING_ELEMENT ("region", region)
+		else PARSE_STRING_ELEMENT ("postcode", postcode)
+		else PARSE_STRING_ELEMENT ("country", country)
+		else PARSE_STRING_ELEMENT ("formattedAddress", formatted_address)
+		else return GDATA_PARSABLE_CLASS (gdata_gd_postal_address_parent_class)->parse_xml (parsable, doc, node, user_data, error);
+	} else {
+		return GDATA_PARSABLE_CLASS (gdata_gd_postal_address_parent_class)->parse_xml (parsable, doc, node, user_data, error);
 	}
 
 	return TRUE;
@@ -656,8 +659,8 @@ get_namespaces (GDataParsable *parsable, GHashTable *namespaces)
 
 /**
  * gdata_gd_postal_address_new:
- * @relation_type: the relationship between the address and its owner, or %NULL
- * @label: a human-readable label for the address, or %NULL
+ * @relation_type: (allow-none): the relationship between the address and its owner, or %NULL
+ * @label: (allow-none): a human-readable label for the address, or %NULL
  * @is_primary: %TRUE if this phone number is its owner's primary number, %FALSE otherwise
  *
  * Creates a new #GDataGDPostalAddress. More information is available in the <ulink type="http"
@@ -680,12 +683,14 @@ gdata_gd_postal_address_new (const gchar *relation_type, const gchar *label, gbo
  * @b: another #GDataGDPostalAddress, or %NULL
  *
  * Compares the two postal addresses in a strcmp() fashion. %NULL values are handled gracefully, with
- * %0 returned if both @a and @b are %NULL, %-1 if @a is %NULL and %1 if @b is %NULL.
+ * <code class="literal">0</code> returned if both @a and @b are %NULL, <code class="literal">-1</code> if @a is %NULL
+ * and <code class="literal">1</code> if @b is %NULL.
  *
  * The comparison of non-%NULL values is done on the basis of the @street, @po_box, @city and @postcode properties of
  * the #GDataGDPostalAddress<!-- -->es.
  *
- * Return value: %0 if @a equals @b, %-1 or %1 as appropriate otherwise
+ * Return value: <code class="literal">0</code> if @a equals @b, <code class="literal">-1</code> or <code class="literal">1</code> as
+ * appropriate otherwise
  *
  * Since: 0.4.0
  **/
@@ -694,7 +699,7 @@ gdata_gd_postal_address_compare (const GDataGDPostalAddress *a, const GDataGDPos
 {
 	if (a == NULL && b != NULL)
 		return -1;
-	else if (b == NULL)
+	else if (a != NULL && b == NULL)
 		return 1;
 
 	if (a == b)
@@ -725,7 +730,7 @@ gdata_gd_postal_address_get_address (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_address:
  * @self: a #GDataGDPostalAddress
- * @address: the new postal address
+ * @address: (allow-none): the new postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:address property to @address.
  *
@@ -735,7 +740,6 @@ void
 gdata_gd_postal_address_set_address (GDataGDPostalAddress *self, const gchar *address)
 {
 	g_return_if_fail (GDATA_IS_GD_POSTAL_ADDRESS (self));
-	g_return_if_fail (address != NULL && *address != '\0');
 
 	/* Trim leading and trailing whitespace from the address.
 	 * See here: http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPostalAddress */
@@ -764,7 +768,7 @@ gdata_gd_postal_address_get_relation_type (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_relation_type:
  * @self: a #GDataGDPostalAddress
- * @relation_type: the new relation type for the postal_address, or %NULL
+ * @relation_type: (allow-none): the new relation type for the postal_address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:relation-type property to @relation_type.
  *
@@ -803,7 +807,7 @@ gdata_gd_postal_address_get_label (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_label:
  * @self: a #GDataGDPostalAddress
- * @label: the new label for the postal address, or %NULL
+ * @label: (allow-none): the new label for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:label property to @label.
  *
@@ -876,7 +880,7 @@ gdata_gd_postal_address_get_mail_class (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_mail_class:
  * @self: a #GDataGDPostalAddress
- * @mail_class: the new mail class for the postal address, or %NULL
+ * @mail_class: (allow-none): the new mail class for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:mail-class property to @mail_class.
  *
@@ -915,7 +919,7 @@ gdata_gd_postal_address_get_usage (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_usage:
  * @self: a #GDataGDPostalAddress
- * @usage: the new usage for the postal address, or %NULL
+ * @usage: (allow-none): the new usage for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:usage property to @usage.
  *
@@ -954,7 +958,7 @@ gdata_gd_postal_address_get_agent (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_agent:
  * @self: a #GDataGDPostalAddress
- * @agent: the new agent for the postal address, or %NULL
+ * @agent: (allow-none): the new agent for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:agent property to @agent.
  *
@@ -993,7 +997,7 @@ gdata_gd_postal_address_get_house_name (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_house_name:
  * @self: a #GDataGDPostalAddress
- * @house_name: the new house name for the postal address, or %NULL
+ * @house_name: (allow-none): the new house name for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:house-name property to @house_name.
  *
@@ -1032,7 +1036,7 @@ gdata_gd_postal_address_get_street (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_street:
  * @self: a #GDataGDPostalAddress
- * @street: the new street for the postal address, or %NULL
+ * @street: (allow-none): the new street for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:street property to @street.
  *
@@ -1071,7 +1075,7 @@ gdata_gd_postal_address_get_po_box (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_po_box:
  * @self: a #GDataGDPostalAddress
- * @po_box: the new P.O. box for the postal address, or %NULL
+ * @po_box: (allow-none): the new P.O. box for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:po-box property to @po_box.
  *
@@ -1110,7 +1114,7 @@ gdata_gd_postal_address_get_neighborhood (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_neighborhood:
  * @self: a #GDataGDPostalAddress
- * @neighborhood: the new neighborhood for the postal address, or %NULL
+ * @neighborhood: (allow-none): the new neighborhood for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:neighborhood property to @neighborhood.
  *
@@ -1149,7 +1153,7 @@ gdata_gd_postal_address_get_city (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_city:
  * @self: a #GDataGDPostalAddress
- * @city: the new city for the postal address, or %NULL
+ * @city: (allow-none): the new city for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:city property to @city.
  *
@@ -1188,7 +1192,7 @@ gdata_gd_postal_address_get_subregion (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_subregion:
  * @self: a #GDataGDPostalAddress
- * @subregion: the new subregion for the postal address, or %NULL
+ * @subregion: (allow-none): the new subregion for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:subregion property to @subregion.
  *
@@ -1227,7 +1231,7 @@ gdata_gd_postal_address_get_region (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_region:
  * @self: a #GDataGDPostalAddress
- * @region: the new region for the postal address, or %NULL
+ * @region: (allow-none): the new region for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:region property to @region.
  *
@@ -1266,7 +1270,7 @@ gdata_gd_postal_address_get_postcode (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_postcode:
  * @self: a #GDataGDPostalAddress
- * @postcode: the new postcode for the postal address, or %NULL
+ * @postcode: (allow-none): the new postcode for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:postcode property to @postcode.
  *
@@ -1322,8 +1326,8 @@ gdata_gd_postal_address_get_country_code (GDataGDPostalAddress *self)
 /**
  * gdata_gd_postal_address_set_country:
  * @self: a #GDataGDPostalAddress
- * @country: the new country for the postal address, or %NULL
- * @country_code: the new country code for the postal address, or %NULL
+ * @country: (allow-none): the new country for the postal address, or %NULL
+ * @country_code: (allow-none): the new country code for the postal address, or %NULL
  *
  * Sets the #GDataGDPostalAddress:country property to @country, and #GDataGDPostalAddress:country-code to @country_code.
  *
