@@ -25,6 +25,8 @@
  *
  * #GDataGDWhen represents a "when" element from the
  * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdWhen">GData specification</ulink>.
+ *
+ * Since: 0.4.0
  **/
 
 #include <glib.h>
@@ -291,16 +293,16 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 {
 	GDataGDWhenPrivate *priv = GDATA_GD_WHEN (parsable)->priv;
 
-	if (xmlStrcmp (node->name, (xmlChar*) "reminder") == 0) {
+	if (gdata_parser_is_namespace (node, "http://schemas.google.com/g/2005") == TRUE &&
+	    xmlStrcmp (node->name, (xmlChar*) "reminder") == 0) {
 		/* gd:reminder */
 		GDataGDReminder *reminder = GDATA_GD_REMINDER (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_REMINDER, doc, node, NULL, error));
 		if (reminder == NULL)
 			return FALSE;
 
 		priv->reminders = g_list_prepend (priv->reminders, reminder);
-	} else if (GDATA_PARSABLE_CLASS (gdata_gd_when_parent_class)->parse_xml (parsable, doc, node, user_data, error) == FALSE) {
-		/* Error! */
-		return FALSE;
+	} else {
+		return GDATA_PARSABLE_CLASS (gdata_gd_when_parent_class)->parse_xml (parsable, doc, node, user_data, error);
 	}
 
 	return TRUE;
@@ -366,7 +368,7 @@ get_namespaces (GDataParsable *parsable, GHashTable *namespaces)
 /**
  * gdata_gd_when_new:
  * @start_time: when the event starts or (for zero-duration events) when it occurs
- * @end_time: when the event ends, or %NULL
+ * @end_time: (allow-none): when the event ends, or %NULL
  * @is_date: %TRUE if @start_time and @end_time specify dates rather than times, %FALSE otherwise
  *
  * Creates a new #GDataGDWhen. More information is available in the <ulink type="http"
@@ -389,11 +391,13 @@ gdata_gd_when_new (GTimeVal *start_time, GTimeVal *end_time, gboolean is_date)
  * @b: another #GDataGDWhen, or %NULL
  *
  * Compares the two times in a strcmp() fashion. %NULL values are handled gracefully, with
- * %0 returned if both @a and @b are %NULL, %-1 if @a is %NULL and %1 if @b is %NULL.
+ * <code class="literal">0</code> returned if both @a and @b are %NULL, <code class="literal">-1</code> if @a is %NULL
+ * and <code class="literal">1</code> if @b is %NULL.
  *
  * The comparison of non-%NULL values is done on the basis of the @start_time, @end_time and @is_date properties of the #GDataGDWhen<!-- -->s.
  *
- * Return value: %0 if @a equals @b, %-1 or %1 as appropriate otherwise
+ * Return value: <code class="literal">0</code> if @a equals @b, <code class="literal">-1</code> or <code class="literal">1</code> as
+ * appropriate otherwise
  *
  * Since: 0.4.0
  **/
@@ -404,7 +408,7 @@ gdata_gd_when_compare (const GDataGDWhen *a, const GDataGDWhen *b)
 
 	if (a == NULL && b != NULL)
 		return -1;
-	else if (b == NULL)
+	else if (a != NULL && b == NULL)
 		return 1;
 
 	if (a == b)
@@ -425,7 +429,7 @@ gdata_gd_when_compare (const GDataGDWhen *a, const GDataGDWhen *b)
 /**
  * gdata_gd_when_get_start_time:
  * @self: a #GDataGDWhen
- * @start_time: return location for the start time
+ * @start_time: (out caller-allocates): return location for the start time
  *
  * Gets the #GDataGDWhen:start-time property and returns it in @start_time.
  *
@@ -461,11 +465,11 @@ gdata_gd_when_set_start_time (GDataGDWhen *self, GTimeVal *start_time)
 /**
  * gdata_gd_when_get_end_time:
  * @self: a #GDataGDWhen
- * @end_time: return location for the end time
+ * @end_time: (out caller-allocates): return location for the end time
  *
  * Gets the #GDataGDWhen:end-time property and returns it in @end_time.
  *
- * If the end time is unset, both fields of the #GTimeVal will be %0.
+ * If the end time is unset, both fields of the #GTimeVal will be <code class="literal">0</code>.
  *
  * Since: 0.4.0
  **/
@@ -480,7 +484,7 @@ gdata_gd_when_get_end_time (GDataGDWhen *self, GTimeVal *end_time)
 /**
  * gdata_gd_when_set_end_time:
  * @self: a #GDataGDWhen
- * @end_time: the new end time, or %NULL
+ * @end_time: (allow-none): the new end time, or %NULL
  *
  * Sets the #GDataGDWhen:end-time property to @end_time.
  *
@@ -556,7 +560,7 @@ gdata_gd_when_get_value_string (GDataGDWhen *self)
 /**
  * gdata_gd_when_set_value_string:
  * @self: a #GDataGDWhen
- * @value_string: the new value string, or %NULL
+ * @value_string: (allow-none): the new value string, or %NULL
  *
  * Sets the #GDataGDWhen:value-string property to @value_string.
  *
@@ -580,7 +584,7 @@ gdata_gd_when_set_value_string (GDataGDWhen *self, const gchar *value_string)
  *
  * Returns a list of the #GDataGDReminder<!-- -->s which are associated with this #GDataGDWhen.
  *
- * Return value: a #GList of #GDataGDReminder<!-- -->s, or %NULL
+ * Return value: (element-type GData.GDReminder) (transfer none): a #GList of #GDataGDReminder<!-- -->s, or %NULL
  *
  * Since: 0.4.0
  **/
