@@ -185,7 +185,7 @@ gdata_service_class_init (GDataServiceClass *klass)
 	 * program should display this to the user, and return their response (the text displayed in the
 	 * image). There is no timeout imposed by the library for the response.
 	 *
-	 * Return value: the text in the CAPTCHA image
+	 * Return value: a newly allocated string containing the text in the CAPTCHA image
 	 **/
 	service_signals[SIGNAL_CAPTCHA_CHALLENGE] = g_signal_new ("captcha-challenge",
 				G_TYPE_FROM_CLASS (klass),
@@ -332,6 +332,10 @@ static void
 real_parse_error_response (GDataService *self, GDataOperationType operation_type, guint status, const gchar *reason_phrase, const gchar *response_body,
 			   gint length, GError **error)
 {
+	/* We prefer to include the @response_body in the error message, but if it's empty, fall back to the @reason_phrase */
+	if (response_body == NULL || *response_body == '\0')
+		response_body = reason_phrase;
+
 	/* See: http://code.google.com/apis/gdata/docs/2.0/reference.html#HTTPStatusCodes */
 	switch (status) {
 		case SOUP_STATUS_CANT_RESOLVE:
@@ -797,9 +801,9 @@ general_error:
  * Other #GDataAuthenticationError errors can be returned for other conditions.
  *
  * If the service requires a CAPTCHA to be completed, the #GDataService::captcha-challenge signal will be emitted. The return value from
- * a signal handler for the signal should be the text from the image. If the text is %NULL or empty, authentication will fail with a
- * %GDATA_AUTHENTICATION_ERROR_CAPTCHA_REQUIRED error. Otherwise, authentication will be automatically and transparently restarted with
- * the new CAPTCHA details.
+ * a signal handler for the signal should be a newly allocated string containing the text from the image. If the text is %NULL or empty,
+ * authentication will fail with a %GDATA_AUTHENTICATION_ERROR_CAPTCHA_REQUIRED error. Otherwise, authentication will be automatically and
+ * transparently restarted with the new CAPTCHA details.
  *
  * A %GDATA_SERVICE_ERROR_PROTOCOL_ERROR will be returned if the server's responses were invalid. Subclasses of #GDataService can override
  * parsing the authentication response, and may return their own error codes. See their documentation for more details.
@@ -892,7 +896,7 @@ query_thread (GSimpleAsyncResult *result, GDataService *service, GCancellable *c
 	/* Execute the query and return */
 	data->feed = gdata_service_query (service, data->feed_uri, data->query, data->entry_type, cancellable,
 					  data->progress_callback, data->progress_user_data, &error);
-	if (data->feed == NULL) {
+	if (data->feed == NULL && error != NULL) {
 		g_simple_async_result_set_from_error (result, error);
 		g_error_free (error);
 	}
@@ -902,13 +906,13 @@ query_thread (GSimpleAsyncResult *result, GDataService *service, GCancellable *c
  * gdata_service_query_async:
  * @self: a #GDataService
  * @feed_uri: the feed URI to query, including the host name and protocol
- * @query: a #GDataQuery with the query parameters, or %NULL
+ * @query: (allow-none): a #GDataQuery with the query parameters, or %NULL
  * @entry_type: a #GType for the #GDataEntry<!-- -->s to build from the XML
  * @cancellable: optional #GCancellable object, or %NULL
- * @progress_callback: a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
- * @progress_user_data: data to pass to the @progress_callback function
+ * @progress_callback: (scope async): a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
+ * @progress_user_data: (closure): data to pass to the @progress_callback function
  * @callback: a #GAsyncReadyCallback to call when the query is finished
- * @user_data: data to pass to the @callback function
+ * @user_data: (closure): data to pass to the @callback function
  *
  * Queries the service's @feed_uri feed to build a #GDataFeed. @self, @feed_uri and
  * @query are all reffed/copied when this function is called, so can safely be freed after this function returns.
@@ -952,7 +956,7 @@ gdata_service_query_async (GDataService *self, const gchar *feed_uri, GDataQuery
  *
  * Finishes an asynchronous query operation started with gdata_service_query_async().
  *
- * Return value: a #GDataFeed of query results, or %NULL; unref with g_object_unref()
+ * Return value: (transfer full): a #GDataFeed of query results, or %NULL; unref with g_object_unref()
  **/
 GDataFeed *
 gdata_service_query_finish (GDataService *self, GAsyncResult *async_result, GError **error)
@@ -971,8 +975,7 @@ gdata_service_query_finish (GDataService *self, GAsyncResult *async_result, GErr
 	data = g_simple_async_result_get_op_res_gpointer (result);
 	if (data->feed != NULL)
 		return g_object_ref (data->feed);
-
-	g_assert_not_reached ();
+	return NULL;
 }
 
 /* Does the bulk of the work of gdata_service_query. Split out because certain queries (such as that done by
@@ -1031,11 +1034,11 @@ _gdata_service_query (GDataService *self, const gchar *feed_uri, GDataQuery *que
  * gdata_service_query:
  * @self: a #GDataService
  * @feed_uri: the feed URI to query, including the host name and protocol
- * @query: a #GDataQuery with the query parameters, or %NULL
+ * @query: (allow-none): a #GDataQuery with the query parameters, or %NULL
  * @entry_type: a #GType for the #GDataEntry<!-- -->s to build from the XML
  * @cancellable: optional #GCancellable object, or %NULL
- * @progress_callback: a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
- * @progress_user_data: data to pass to the @progress_callback function
+ * @progress_callback: (scope call): a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
+ * @progress_user_data: (closure): data to pass to the @progress_callback function
  * @error: a #GError, or %NULL
  *
  * Queries the service's @feed_uri feed to build a #GDataFeed.
@@ -1055,7 +1058,7 @@ _gdata_service_query (GDataService *self, const gchar *feed_uri, GDataQuery *que
  * If the #GDataQuery's ETag is set and it finds a match on the server, %NULL will be returned, but @error will remain unset. Otherwise,
  * @query's ETag will be updated with the ETag from the returned feed, if available.
  *
- * Return value: a #GDataFeed of query results, or %NULL; unref with g_object_unref()
+ * Return value: (transfer full): a #GDataFeed of query results, or %NULL; unref with g_object_unref()
  **/
 GDataFeed *
 gdata_service_query (GDataService *self, const gchar *feed_uri, GDataQuery *query, GType entry_type,
@@ -1149,8 +1152,8 @@ insert_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancell
  * @upload_uri: the URI to which the upload should be sent
  * @entry: the #GDataEntry to insert
  * @cancellable: optional #GCancellable object, or %NULL
- * @callback: a #GAsyncReadyCallback to call when insertion is finished
- * @user_data: data to pass to the @callback function
+ * @callback: a #GAsyncReadyCallback to call when insertion is finished, or %NULL
+ * @user_data: (closure): data to pass to the @callback function
  *
  * Inserts @entry by uploading it to the online service at @upload_uri. @self, @upload_uri and
  * @entry are all reffed/copied when this function is called, so can safely be freed after this function returns.
@@ -1191,7 +1194,7 @@ gdata_service_insert_entry_async (GDataService *self, const gchar *upload_uri, G
  *
  * Finishes an asynchronous entry insertion operation started with gdata_service_insert_entry_async().
  *
- * Return value: an updated #GDataEntry, or %NULL; unref with g_object_unref()
+ * Return value: (transfer full): an updated #GDataEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.3.0
  **/
@@ -1239,7 +1242,7 @@ gdata_service_insert_entry_finish (GDataService *self, GAsyncResult *async_resul
  * If there is an error inserting the entry, a %GDATA_SERVICE_ERROR_PROTOCOL_ERROR error will be returned. Currently, subclasses
  * <emphasis>cannot</emphasis> cannot override this or provide more specific errors.
  *
- * Return value: an updated #GDataEntry, or %NULL
+ * Return value: (transfer full): an updated #GDataEntry, or %NULL; unref with g_object_unref()
  **/
 GDataEntry *
 gdata_service_insert_entry (GDataService *self, const gchar *upload_uri, GDataEntry *entry, GCancellable *cancellable, GError **error)
@@ -1334,8 +1337,8 @@ update_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancell
  * @self: a #GDataService
  * @entry: the #GDataEntry to update
  * @cancellable: optional #GCancellable object, or %NULL
- * @callback: a #GAsyncReadyCallback to call when the update is finished
- * @user_data: data to pass to the @callback function
+ * @callback: a #GAsyncReadyCallback to call when the update is finished, or %NULL
+ * @user_data: (closure): data to pass to the @callback function
  *
  * Updates @entry by PUTting it to its <literal>edit</literal> link's URI. @self and
  * @entry are both reffed when this function is called, so can safely be unreffed after this function returns.
@@ -1369,7 +1372,7 @@ gdata_service_update_entry_async (GDataService *self, GDataEntry *entry, GCancel
  *
  * Finishes an asynchronous entry update operation started with gdata_service_update_entry_async().
  *
- * Return value: an updated #GDataEntry, or %NULL; unref with g_object_unref()
+ * Return value: (transfer full): an updated #GDataEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.3.0
  **/
@@ -1413,7 +1416,7 @@ gdata_service_update_entry_finish (GDataService *self, GAsyncResult *async_resul
  * If there is an error updating the entry, a %GDATA_SERVICE_ERROR_PROTOCOL_ERROR error will be returned. Currently, subclasses
  * <emphasis>cannot</emphasis> cannot override this or provide more specific errors.
  *
- * Return value: an updated #GDataEntry, or %NULL
+ * Return value: (transfer full): an updated #GDataEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.2.0
  **/
@@ -1511,8 +1514,8 @@ delete_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancell
  * @self: a #GDataService
  * @entry: the #GDataEntry to delete
  * @cancellable: optional #GCancellable object, or %NULL
- * @callback: a #GAsyncReadyCallback to call when deletion is finished
- * @user_data: data to pass to the @callback function
+ * @callback: a #GAsyncReadyCallback to call when deletion is finished, or %NULL
+ * @user_data: (closure): data to pass to the @callback function
  *
  * Deletes @entry from the server. @self and @entry are both reffed when this function is called,
  * so can safely be unreffed after this function returns.
@@ -1651,7 +1654,7 @@ notify_proxy_uri_cb (GObject *gobject, GParamSpec *pspec, GObject *self)
  *
  * Gets the proxy URI on the #GDataService's #SoupSession.
  *
- * Return value: the proxy URI, or %NULL
+ * Return value: (transfer none): the proxy URI, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -1671,7 +1674,7 @@ gdata_service_get_proxy_uri (GDataService *self)
 /**
  * gdata_service_set_proxy_uri:
  * @self: a #GDataService
- * @proxy_uri: the proxy URI
+ * @proxy_uri: (allow-none): the proxy URI, or %NULL
  *
  * Sets the proxy URI on the #SoupSession used internally by the given #GDataService.
  * This forces all requests through the given proxy.
