@@ -27,6 +27,8 @@
  *
  * For more details of Google Contacts' GData API, see the <ulink type="http" url="http://code.google.com/apis/contacts/docs/2.0/reference.html">
  * online documentation</ulink>.
+ *
+ * Since: 0.2.0
  **/
 
 #include <config.h>
@@ -288,15 +290,10 @@ gdata_contacts_contact_new (const gchar *id)
 static gboolean
 parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_data, GError **error)
 {
-	GDataContactsContact *self;
+	GDataContactsContact *self = GDATA_CONTACTS_CONTACT (parsable);
 
-	g_return_val_if_fail (GDATA_IS_CONTACTS_CONTACT (parsable), FALSE);
-	g_return_val_if_fail (doc != NULL, FALSE);
-	g_return_val_if_fail (node != NULL, FALSE);
-
-	self = GDATA_CONTACTS_CONTACT (parsable);
-
-	if (xmlStrcmp (node->name, (xmlChar*) "edited") == 0) {
+	if (gdata_parser_is_namespace (node, "http://www.w3.org/2007/app") == TRUE &&
+	    xmlStrcmp (node->name, (xmlChar*) "edited") == 0) {
 		/* app:edited */
 		/* TODO: Should be in GDataEntry? */
 		xmlChar *edited = xmlNodeListGetString (doc, node->children, TRUE);
@@ -307,82 +304,90 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 			return FALSE;
 		}
 		g_free (edited);
-	} else if (xmlStrcmp (node->name, (xmlChar*) "name") == 0) {
-		/* gd:name */
-		GDataGDName *name = GDATA_GD_NAME (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_NAME, doc, node, NULL, error));
-		if (name == NULL)
-			return FALSE;
+	} else if (gdata_parser_is_namespace (node, "http://schemas.google.com/g/2005") == TRUE) {
+		if (xmlStrcmp (node->name, (xmlChar*) "name") == 0) {
+			/* gd:name */
+			GDataGDName *name = GDATA_GD_NAME (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_NAME, doc, node, NULL, error));
+			if (name == NULL)
+				return FALSE;
 
-		if (self->priv->name != NULL)
-			g_object_unref (self->priv->name);
-		self->priv->name = name;
-	} else if (xmlStrcmp (node->name, (xmlChar*) "email") == 0) {
-		/* gd:email */
-		GDataGDEmailAddress *email = GDATA_GD_EMAIL_ADDRESS (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_EMAIL_ADDRESS, doc,
-													node, NULL, error));
-		if (email == NULL)
-			return FALSE;
+			if (self->priv->name != NULL)
+				g_object_unref (self->priv->name);
+			self->priv->name = name;
+		} else if (xmlStrcmp (node->name, (xmlChar*) "email") == 0) {
+			/* gd:email */
+			GDataGDEmailAddress *email = GDATA_GD_EMAIL_ADDRESS (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_EMAIL_ADDRESS, doc,
+														node, NULL, error));
+			if (email == NULL)
+				return FALSE;
 
-		gdata_contacts_contact_add_email_address (self, email);
-	} else if (xmlStrcmp (node->name, (xmlChar*) "im") == 0) {
-		/* gd:im */
-		GDataGDIMAddress *im = GDATA_GD_IM_ADDRESS (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_IM_ADDRESS, doc, node, NULL, error));
-		if (im == NULL)
-			return FALSE;
+			gdata_contacts_contact_add_email_address (self, email);
+		} else if (xmlStrcmp (node->name, (xmlChar*) "im") == 0) {
+			/* gd:im */
+			GDataGDIMAddress *im = GDATA_GD_IM_ADDRESS (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_IM_ADDRESS, doc, node, NULL, error));
+			if (im == NULL)
+				return FALSE;
 
-		gdata_contacts_contact_add_im_address (self, im);
-	} else if (xmlStrcmp (node->name, (xmlChar*) "phoneNumber") == 0) {
-		/* gd:phoneNumber */
-		GDataGDPhoneNumber *number = GDATA_GD_PHONE_NUMBER (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_PHONE_NUMBER, doc,
-												       node, NULL, error));
-		if (number == NULL)
-			return FALSE;
+			gdata_contacts_contact_add_im_address (self, im);
+		} else if (xmlStrcmp (node->name, (xmlChar*) "phoneNumber") == 0) {
+			/* gd:phoneNumber */
+			GDataGDPhoneNumber *number = GDATA_GD_PHONE_NUMBER (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_PHONE_NUMBER, doc,
+													       node, NULL, error));
+			if (number == NULL)
+				return FALSE;
 
-		gdata_contacts_contact_add_phone_number (self, number);
-	} else if (xmlStrcmp (node->name, (xmlChar*) "structuredPostalAddress") == 0) {
-		/* gd:structuredPostalAddress — deprecates gd:postalAddress */
-		GDataGDPostalAddress *address = GDATA_GD_POSTAL_ADDRESS (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_POSTAL_ADDRESS,
-													    doc, node, NULL, error));
-		if (address == NULL)
-			return FALSE;
+			gdata_contacts_contact_add_phone_number (self, number);
+		} else if (xmlStrcmp (node->name, (xmlChar*) "structuredPostalAddress") == 0) {
+			/* gd:structuredPostalAddress — deprecates gd:postalAddress */
+			GDataGDPostalAddress *address = GDATA_GD_POSTAL_ADDRESS (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_POSTAL_ADDRESS,
+														    doc, node, NULL, error));
+			if (address == NULL)
+				return FALSE;
 
-		gdata_contacts_contact_add_postal_address (self, address);
-	} else if (xmlStrcmp (node->name, (xmlChar*) "organization") == 0) {
-		/* gd:organization */
-		GDataGDOrganization *organization = GDATA_GD_ORGANIZATION (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_ORGANIZATION,
-													      doc, node, NULL, error));
-		if (organization == NULL)
-			return FALSE;
+			gdata_contacts_contact_add_postal_address (self, address);
+		} else if (xmlStrcmp (node->name, (xmlChar*) "organization") == 0) {
+			/* gd:organization */
+			GDataGDOrganization *organization = GDATA_GD_ORGANIZATION (_gdata_parsable_new_from_xml_node (GDATA_TYPE_GD_ORGANIZATION,
+														      doc, node, NULL, error));
+			if (organization == NULL)
+				return FALSE;
 
-		gdata_contacts_contact_add_organization (self, organization);
-	} else if (xmlStrcmp (node->name, (xmlChar*) "extendedProperty") == 0) {
-		/* gd:extendedProperty */
-		xmlChar *name, *value;
-		xmlBuffer *buffer = NULL;
+			gdata_contacts_contact_add_organization (self, organization);
+		} else if (xmlStrcmp (node->name, (xmlChar*) "extendedProperty") == 0) {
+			/* gd:extendedProperty */
+			xmlChar *name, *value;
+			xmlBuffer *buffer = NULL;
 
-		name = xmlGetProp (node, (xmlChar*) "name");
-		if (name == NULL)
-			return gdata_parser_error_required_property_missing (node, "name", error);
+			name = xmlGetProp (node, (xmlChar*) "name");
+			if (name == NULL)
+				return gdata_parser_error_required_property_missing (node, "name", error);
 
-		/* Get either the value property, or the element's content */
-		value = xmlGetProp (node, (xmlChar*) "value");
-		if (value == NULL) {
-			xmlNode *child_node;
+			/* Get either the value property, or the element's content */
+			value = xmlGetProp (node, (xmlChar*) "value");
+			if (value == NULL) {
+				xmlNode *child_node;
 
-			/* Use the element's content instead (arbitrary XML) */
-			buffer = xmlBufferCreate ();
-			for (child_node = node->children; child_node != NULL; child_node = child_node->next)
-				xmlNodeDump (buffer, doc, child_node, 0, 0);
-			value = (xmlChar*) xmlBufferContent (buffer);
+				/* Use the element's content instead (arbitrary XML) */
+				buffer = xmlBufferCreate ();
+				for (child_node = node->children; child_node != NULL; child_node = child_node->next)
+					xmlNodeDump (buffer, doc, child_node, 0, 0);
+				value = (xmlChar*) xmlBufferContent (buffer);
+			}
+
+			gdata_contacts_contact_set_extended_property (self, (gchar*) name, (gchar*) value);
+
+			if (buffer != NULL)
+				xmlBufferFree (buffer);
+			else
+				g_free (value);
+		} else if (xmlStrcmp (node->name, (xmlChar*) "deleted") == 0) {
+			/* gd:deleted */
+			self->priv->deleted = TRUE;
+		} else {
+			return GDATA_PARSABLE_CLASS (gdata_contacts_contact_parent_class)->parse_xml (parsable, doc, node, user_data, error);
 		}
-
-		gdata_contacts_contact_set_extended_property (self, (gchar*) name, (gchar*) value);
-
-		if (buffer != NULL)
-			xmlBufferFree (buffer);
-		else
-			g_free (value);
-	} else if (xmlStrcmp (node->name, (xmlChar*) "groupMembershipInfo") == 0) {
+	} else if (gdata_parser_is_namespace (node, "http://schemas.google.com/contact/2008") == TRUE &&
+	           xmlStrcmp (node->name, (xmlChar*) "groupMembershipInfo") == 0) {
 		/* gContact:groupMembershipInfo */
 		xmlChar *href, *deleted;
 		gboolean deleted_bool;
@@ -406,9 +411,6 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 
 		/* Insert it into the hash table */
 		g_hash_table_insert (self->priv->groups, (gchar*) href, GUINT_TO_POINTER (deleted_bool));
-	} else if (xmlStrcmp (node->name, (xmlChar*) "deleted") == 0) {
-		/* gd:deleted */
-		self->priv->deleted = TRUE;
 	} else {
 		/* If we haven't yet found a photo, check to see if it's a photo <link> element */
 		if (self->priv->photo_etag == NULL && xmlStrcmp (node->name, (xmlChar*) "link") == 0) {
@@ -421,10 +423,7 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 			xmlFree (rel);
 		}
 
-		if (GDATA_PARSABLE_CLASS (gdata_contacts_contact_parent_class)->parse_xml (parsable, doc, node, user_data, error) == FALSE) {
-			/* Error! */
-			return FALSE;
-		}
+		return GDATA_PARSABLE_CLASS (gdata_contacts_contact_parent_class)->parse_xml (parsable, doc, node, user_data, error);
 	}
 
 	return TRUE;
@@ -448,7 +447,15 @@ get_extended_property_xml_cb (const gchar *name, const gchar *value, GString *xm
 static void
 get_group_xml_cb (const gchar *href, gpointer deleted, GString *xml_string)
 {
-	g_string_append_printf (xml_string, "<gContact:groupMembershipInfo href='%s'/>", href);
+	gchar *full_pos, *uri = g_strdup (href);
+
+	/* The service API sometimes stubbornly insists on using the "full" view instead of the "base" view, which we have
+	 * to fix, or it complains about an invalid group ID. */
+	full_pos = strstr (uri, "/full/");
+	if (full_pos != NULL)
+		memcpy ((char*) full_pos, "/base/", 6);
+
+	g_string_append_printf (xml_string, "<gContact:groupMembershipInfo href='%s'/>", uri);
 }
 
 static void
@@ -495,10 +502,10 @@ get_namespaces (GDataParsable *parsable, GHashTable *namespaces)
 /**
  * gdata_contacts_contact_get_edited:
  * @self: a #GDataContactsContact
- * @edited: a #GTimeVal
+ * @edited: (out caller-allocates): a #GTimeVal
  *
  * Gets the #GDataContactsContact:edited property and puts it in @edited. If the property is unset,
- * both fields in the #GTimeVal will be set to %0.
+ * both fields in the #GTimeVal will be set to <code class="literal">0</code>.
  *
  * Since: 0.2.0
  **/
@@ -516,7 +523,7 @@ gdata_contacts_contact_get_edited (GDataContactsContact *self, GTimeVal *edited)
  *
  * Gets the #GDataContactsContact:name property.
  *
- * Return value: the contact's name, or %NULL
+ * Return value: (transfer none): the contact's name, or %NULL
  *
  * Since: 0.5.0
  **/
@@ -584,7 +591,7 @@ gdata_contacts_contact_add_email_address (GDataContactsContact *self, GDataGDEma
  *
  * Gets a list of the e-mail addresses owned by the contact.
  *
- * Return value: a #GList of #GDataGDEmailAddress<!-- -->es, or %NULL
+ * Return value: (element-type GData.GDEmailAddress) (transfer none): a #GList of #GDataGDEmailAddress<!-- -->es, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -601,7 +608,7 @@ gdata_contacts_contact_get_email_addresses (GDataContactsContact *self)
  *
  * Gets the contact's primary e-mail address, if one exists.
  *
- * Return value: a #GDataGDEmailAddress, or %NULL
+ * Return value: (transfer none): a #GDataGDEmailAddress, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -673,7 +680,7 @@ gdata_contacts_contact_add_im_address (GDataContactsContact *self, GDataGDIMAddr
  *
  * Gets a list of the IM addresses owned by the contact.
  *
- * Return value: a #GList of #GDataGDIMAddress<!-- -->es, or %NULL
+ * Return value: (element-type GData.GDIMAddress) (transfer none): a #GList of #GDataGDIMAddress<!-- -->es, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -690,7 +697,7 @@ gdata_contacts_contact_get_im_addresses (GDataContactsContact *self)
  *
  * Gets the contact's primary IM address, if one exists.
  *
- * Return value: a #GDataGDIMAddress, or %NULL
+ * Return value: (transfer none): a #GDataGDIMAddress, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -762,7 +769,7 @@ gdata_contacts_contact_add_phone_number (GDataContactsContact *self, GDataGDPhon
  *
  * Gets a list of the phone numbers owned by the contact.
  *
- * Return value: a #GList of #GDataGDPhoneNumber<!-- -->s, or %NULL
+ * Return value: (element-type GData.GDPhoneNumber) (transfer none): a #GList of #GDataGDPhoneNumber<!-- -->s, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -779,7 +786,7 @@ gdata_contacts_contact_get_phone_numbers (GDataContactsContact *self)
  *
  * Gets the contact's primary phone number, if one exists.
  *
- * Return value: a #GDataGDPhoneNumber, or %NULL
+ * Return value: (transfer none): a #GDataGDPhoneNumber, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -851,7 +858,7 @@ gdata_contacts_contact_add_postal_address (GDataContactsContact *self, GDataGDPo
  *
  * Gets a list of the postal addresses owned by the contact.
  *
- * Return value: a #GList of #GDataGDPostalAddress<!-- -->es, or %NULL
+ * Return value: (element-type GData.GDPostalAddress) (transfer none): a #GList of #GDataGDPostalAddress<!-- -->es, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -868,7 +875,7 @@ gdata_contacts_contact_get_postal_addresses (GDataContactsContact *self)
  *
  * Gets the contact's primary postal address, if one exists.
  *
- * Return value: a #GDataGDPostalAddress, or %NULL
+ * Return value: (transfer none): a #GDataGDPostalAddress, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -940,7 +947,7 @@ gdata_contacts_contact_add_organization (GDataContactsContact *self, GDataGDOrga
  *
  * Gets a list of the organizations to which the contact belongs.
  *
- * Return value: a #GList of #GDataGDOrganization<!-- -->s, or %NULL
+ * Return value: (element-type GData.GDOrganization) (transfer none): a #GList of #GDataGDOrganization<!-- -->s, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -957,7 +964,7 @@ gdata_contacts_contact_get_organizations (GDataContactsContact *self)
  *
  * Gets the contact's primary organization, if one exists.
  *
- * Return value: a #GDataGDOrganization, or %NULL
+ * Return value: (transfer none): a #GDataGDOrganization, or %NULL
  *
  * Since: 0.2.0
  **/
@@ -1024,7 +1031,7 @@ gdata_contacts_contact_get_extended_property (GDataContactsContact *self, const
  *
  * Gets the full list of extended properties of the contact; a hash table mapping property name to value.
  *
- * Return value: a #GHashTable of extended properties
+ * Return value: (transfer none): a #GHashTable of extended properties
  *
  * Since: 0.4.0
  **/
@@ -1039,7 +1046,7 @@ gdata_contacts_contact_get_extended_properties (GDataContactsContact *self)
  * gdata_contacts_contact_set_extended_property:
  * @self: a #GDataContactsContact
  * @name: the property name; an arbitrary, unique string
- * @value: the property value, or %NULL
+ * @value: (allow-none): the property value, or %NULL
  *
  * Sets the value of a contact's extended property. Extended property names are unique (but of the client's choosing),
  * and reusing the same property name will result in the old value of that property being overwritten.
@@ -1094,7 +1101,7 @@ gdata_contacts_contact_add_group (GDataContactsContact *self, const gchar *href)
 {
 	g_return_if_fail (GDATA_IS_CONTACTS_CONTACT (self));
 	g_return_if_fail (href != NULL);
-	g_hash_table_insert (self->priv->groups, (gchar*) href, GUINT_TO_POINTER (FALSE));
+	g_hash_table_insert (self->priv->groups, g_strdup (href), GUINT_TO_POINTER (FALSE));
 }
 
 /**
@@ -1147,14 +1154,14 @@ get_groups_cb (const gchar *href, gpointer deleted, GList **groups)
  *
  * Gets a list of the groups to which the contact belongs.
  *
- * Return value: a #GList of constant group ID URIs, or %NULL; free with g_list_free()
+ * Return value: (element-type utf8) (transfer container): a #GList of constant group ID URIs, or %NULL; free with g_list_free()
  *
  * Since: 0.2.0
  **/
 GList *
 gdata_contacts_contact_get_groups (GDataContactsContact *self)
 {
-	GList *groups;
+	GList *groups = NULL;
 
 	g_return_val_if_fail (GDATA_IS_CONTACTS_CONTACT (self), NULL);
 
@@ -1209,8 +1216,8 @@ gdata_contacts_contact_has_photo (GDataContactsContact *self)
  * gdata_contacts_contact_get_photo:
  * @self: a #GDataContactsContact
  * @service: a #GDataContactsService
- * @length: return location for the image length, in bytes
- * @content_type: return location for the image's content type, or %NULL; free with g_free()
+ * @length: (out caller-allocates): return location for the image length, in bytes
+ * @content_type: (out callee-allocates) (transfer full) (allow-none): return location for the image's content type, or %NULL; free with g_free()
  * @cancellable: optional #GCancellable object, or %NULL
  * @error: a #GError, or %NULL
  *
@@ -1298,8 +1305,8 @@ gdata_contacts_contact_get_photo (GDataContactsContact *self, GDataContactsServi
  * gdata_contacts_contact_set_photo:
  * @self: a #GDataContactsContact
  * @service: a #GDataService
- * @data: the image data, or %NULL
- * @length: the image length, in bytes, or %0
+ * @data: (allow-none): the image data, or %NULL
+ * @length: the image length, in bytes, or <code class="literal">0</code>
  * @cancellable: optional #GCancellable object, or %NULL
  * @error: a #GError, or %NULL
  *
