@@ -2,6 +2,7 @@
 /*
  * GData Client
  * Copyright (C) Thibault Saunier 2009 <saunierthibault@gmail.com>
+ * Copyright (C) Philip Withnall 2010 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,6 +29,8 @@
  *
  * For more information on the custom GData query parameters supported by #GDataDocumentsQuery, see the <ulink type="http"
  * url="http://code.google.com/apis/documents/docs/2.0/reference.html#Parameters">online documentation</ulink>.
+ *
+ * Since: 0.4.0
  **/
 
 #include <config.h>
@@ -234,7 +237,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 
 	if (entry_id == NULL && priv->folder_id != NULL) {
 		g_string_append (query_uri, "/folder%3A");
-		g_string_append_uri_escaped (query_uri, priv->folder_id, NULL, TRUE);
+		g_string_append_uri_escaped (query_uri, priv->folder_id, NULL, FALSE);
 	}
 
 	/* Chain up to the parent class */
@@ -250,10 +253,10 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 		collaborator_address = priv->collaborator_addresses;
 
 		g_string_append (query_uri, "writer=");
-		g_string_append_uri_escaped (query_uri, gdata_gd_email_address_get_address (collaborator_address->data), NULL, TRUE);
+		g_string_append_uri_escaped (query_uri, gdata_gd_email_address_get_address (collaborator_address->data), NULL, FALSE);
 		for (collaborator_address = collaborator_address->next; collaborator_address != NULL; collaborator_address = collaborator_address->next) {
 			g_string_append_c (query_uri, ';');
-			g_string_append_uri_escaped (query_uri, gdata_gd_email_address_get_address (collaborator_address->data), NULL, TRUE);
+			g_string_append_uri_escaped (query_uri, gdata_gd_email_address_get_address (collaborator_address->data), NULL, FALSE);
 		}
 	}
 
@@ -263,17 +266,17 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 		reader_address = priv->reader_addresses;
 
 		g_string_append (query_uri, "reader=");
-		g_string_append_uri_escaped (query_uri, gdata_gd_email_address_get_address (reader_address->data), NULL, TRUE);
+		g_string_append_uri_escaped (query_uri, gdata_gd_email_address_get_address (reader_address->data), NULL, FALSE);
 		for (reader_address = reader_address->next; reader_address != NULL; reader_address = reader_address->next) {
 			g_string_append_c (query_uri, ';');
-			g_string_append_uri_escaped (query_uri, gdata_gd_email_address_get_address (reader_address->data), NULL, TRUE);
+			g_string_append_uri_escaped (query_uri, gdata_gd_email_address_get_address (reader_address->data), NULL, FALSE);
 		}
 	}
 
 	if (priv->title != NULL) {
 		APPEND_SEP
 		g_string_append (query_uri, "title=");
-		g_string_append_uri_escaped (query_uri, priv->title, NULL, TRUE);
+		g_string_append_uri_escaped (query_uri, priv->title, NULL, FALSE);
 		if (priv->exact_title == TRUE)
 			g_string_append (query_uri, "&title-exact=true");
 	}
@@ -292,7 +295,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 
 /**
  * gdata_documents_query_new:
- * @q: a query string
+ * @q: (allow-none): a query string, or %NULL
  *
  * Creates a new #GDataDocumentsQuery with its #GDataQuery:q property set to @q.
  *
@@ -308,9 +311,9 @@ gdata_documents_query_new (const gchar *q)
 
 /**
  * gdata_documents_query_new_with_limits:
- * @q: a query string
- * @start_index: a one-based start index for the results
- * @max_results: the maximum number of results to return
+ * @q: (allow-none): a query string, or %NULL
+ * @start_index: a one-based start index for the results, or <code class="literal">0</code>
+ * @max_results: the maximum number of results to return, or <code class="literal">0</code>
  *
  * Creates a new #GDataDocumentsQuery with its #GDataQuery:q property set to @q, and the limits @start_index and @max_results
  * applied.
@@ -361,6 +364,9 @@ gdata_documents_query_set_show_deleted (GDataDocumentsQuery *self, gboolean show
 	g_return_if_fail (GDATA_IS_DOCUMENTS_QUERY (self));
 	self->priv->show_deleted = show_deleted;
 	g_object_notify (G_OBJECT (self), "show-deleted");
+
+	/* Our current ETag will no longer be relevant */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -395,6 +401,9 @@ gdata_documents_query_set_show_folders (GDataDocumentsQuery *self, gboolean show
 	g_return_if_fail (GDATA_IS_DOCUMENTS_QUERY (self));
 	self->priv->show_folders = show_folders;
 	g_object_notify (G_OBJECT (self), "show-folders");
+
+	/* Our current ETag will no longer be relevant */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -417,7 +426,7 @@ gdata_documents_query_get_folder_id (GDataDocumentsQuery *self)
 /**
  * gdata_documents_query_set_folder_id:
  * @self: a #GDataDocumentsQuery
- * @folder_id: the ID of the folder to be queried, or %NULL
+ * @folder_id: (allow-none): the ID of the folder to be queried, or %NULL
  *
  * Sets the #GDataDocumentsQuery:folder-id property to @folder_id.
  *
@@ -433,6 +442,9 @@ gdata_documents_query_set_folder_id (GDataDocumentsQuery *self, const gchar *fol
 	g_free (self->priv->folder_id);
 	self->priv->folder_id = g_strdup (folder_id);
 	g_object_notify (G_OBJECT (self), "folder-id");
+
+	/* Our current ETag will no longer be relevant */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -472,7 +484,7 @@ gdata_documents_query_get_exact_title (GDataDocumentsQuery *self)
 /**
  * gdata_documents_query_set_title:
  * @self: a #GDataDocumentsQuery
- * @title: the title (or title fragment) to query for, or %NULL
+ * @title: (allow-none): the title (or title fragment) to query for, or %NULL
  * @exact_title: %TRUE if the query should match the exact @title, %FALSE otherwise
  *
  * Sets the #GDataDocumentsQuery:title property to @title.
@@ -494,6 +506,9 @@ gdata_documents_query_set_title (GDataDocumentsQuery *self, const gchar *title,
 	g_object_notify (G_OBJECT (self), "exact-title");
 	g_object_notify (G_OBJECT (self), "title");
 	g_object_thaw_notify (G_OBJECT (self));
+
+	/* Our current ETag will no longer be relevant */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -502,7 +517,8 @@ gdata_documents_query_set_title (GDataDocumentsQuery *self, const gchar *title,
  *
  * Gets a list of #GDataGDEmailAddress<!-- -->es of the document collaborators whose documents will be queried.
  *
- * Return value: a list of #GDataGDEmailAddress<!-- -->es of the collaborators concerned by the query, or %NULL
+ * Return value: (element-type GData.GDEmailAddress) (transfer none): a list of #GDataGDEmailAddress<!-- -->es of the collaborators concerned by the
+ * query, or %NULL
  *
  * Since: 0.4.0
  **/
@@ -519,7 +535,8 @@ gdata_documents_query_get_collaborator_addresses (GDataDocumentsQuery *self)
  *
  * Gets a list of #GDataGDEmailAddress<!-- -->es of the document readers whose documents will be queried.
  *
- * Return value: a list of #GDataGDEmailAddress<!-- -->es of the readers concerned by the query, or %NULL
+ * Return value: (element-type GData.GDEmailAddress) (transfer none): a list of #GDataGDEmailAddress<!-- -->es of the readers concerned by the query,
+ * or %NULL
  *
  * Since: 0.4.0
  **/
@@ -549,6 +566,9 @@ gdata_documents_query_add_reader (GDataDocumentsQuery *self, const gchar *email_
 
 	address = gdata_gd_email_address_new (email_address, "reader", NULL, FALSE);
 	self->priv->reader_addresses = g_list_append (self->priv->reader_addresses, address);
+
+	/* Our current ETag will no longer be relevant */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -570,4 +590,7 @@ gdata_documents_query_add_collaborator (GDataDocumentsQuery *self, const gchar *
 
 	address = gdata_gd_email_address_new (email_address, "collaborator", NULL, FALSE);
 	self->priv->collaborator_addresses = g_list_append (self->priv->collaborator_addresses, address);
+
+	/* Our current ETag will no longer be relevant */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
