@@ -2,7 +2,7 @@
 /*
  * GData Client
  * Copyright (C) Richard Schwarting 2009 <aquarichy@gmail.com>
- * Copyright (C) Philip Withnall 2009 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2009–2010 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,8 @@
  *
  * For more details of PicasaWeb's GData API, see the <ulink type="http" url="http://code.google.com/apis/picasaweb/developers_guide_protocol.html">
  * online documentation</ulink>.
+ *
+ * Since: 0.4.0
  **/
 
 #include <config.h>
@@ -62,12 +64,14 @@ gdata_picasaweb_service_init (GDataPicasaWebService *self)
 /*
  * create_uri:
  * @self: a #GDataPicasaWebService
- * @username: the username to use, or %NULL to use the currently logged in user
+ * @username: (allow-none): the username to use, or %NULL to use the currently logged in user
  * @type: the type of object to access: "entry" for a user, or "feed" for an album
  *
  * Builds a URI to use when querying for albums or a user.
  *
  * Return value: a constructed URI; free with g_free()
+ *
+ * Since: 0.4.0
  */
 static gchar *
 create_uri (GDataPicasaWebService *self, const gchar *username, const gchar *type)
@@ -105,15 +109,15 @@ gdata_picasaweb_service_new (const gchar *client_id)
 }
 
 /**
- * gdata_picasaweb_service_get_user
+ * gdata_picasaweb_service_get_user:
  * @self: a #GDataPicasaWebService
- * @username: the username of the user whose information you wish to retrieve, or %NULL for the currently authenticated user.
+ * @username: (allow-none): the username of the user whose information you wish to retrieve, or %NULL for the currently authenticated user.
  * @cancellable: optional #GCancellable object, or %NULL
  * @error: a #GError, or %NULL
  *
  * Queries the service to return the user specified by @username.
  *
- * Return value: a #GDataPicasaWebUser; unref with g_object_unref()
+ * Return value: (transfer full): a #GDataPicasaWebUser; unref with g_object_unref()
  *
  * Since: 0.6.0
  **/
@@ -132,7 +136,10 @@ gdata_picasaweb_service_get_user (GDataPicasaWebService *self, const gchar *user
 				     _("You must specify a username or be authenticated to query a user."));
 		return NULL;
 	}
+
 	message = _gdata_service_query (GDATA_SERVICE (self), uri, NULL, cancellable, NULL, NULL, error);
+	g_free (uri);
+
 	if (message == NULL)
 		return NULL;
 
@@ -146,11 +153,11 @@ gdata_picasaweb_service_get_user (GDataPicasaWebService *self, const gchar *user
 /**
  * gdata_picasaweb_service_query_all_albums:
  * @self: a #GDataPicasaWebService
- * @query: a #GDataQuery with the query parameters, or %NULL
- * @username: the username of the user whose albums you wish to retrieve, or %NULL
+ * @query: (allow-none): a #GDataQuery with the query parameters, or %NULL
+ * @username: (allow-none): the username of the user whose albums you wish to retrieve, or %NULL
  * @cancellable: optional #GCancellable object, or %NULL
- * @progress_callback: a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
- * @progress_user_data: data to pass to the @progress_callback function
+ * @progress_callback: (scope call): a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
+ * @progress_user_data: (closure): data to pass to the @progress_callback function
  * @error: a #GError, or %NULL
  *
  * Queries the service to return a list of all albums belonging to the specified @username which match the given
@@ -161,7 +168,7 @@ gdata_picasaweb_service_get_user (GDataPicasaWebService *self, const gchar *user
  *
  * For more details, see gdata_service_query().
  *
- * Return value: a #GDataFeed of query results; unref with g_object_unref()
+ * Return value: (transfer full): a #GDataFeed of query results; unref with g_object_unref()
  *
  * Since: 0.4.0
  **/
@@ -198,15 +205,15 @@ gdata_picasaweb_service_query_all_albums (GDataPicasaWebService *self, GDataQuer
 }
 
 /**
- * gdata_picasaweb_service_query_all_albums_async:
+ * gdata_picasaweb_service_query_all_albums_async: (skip)
  * @self: a #GDataPicasaWebService
- * @query: a #GDataQuery with the query parameters, or %NULL
- * @username: the username of the user whose albums you wish to retrieve, or %NULL
+ * @query: (allow-none): a #GDataQuery with the query parameters, or %NULL
+ * @username: (allow-none): the username of the user whose albums you wish to retrieve, or %NULL
  * @cancellable: optional #GCancellable object, or %NULL
  * @progress_callback: a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
- * @progress_user_data: data to pass to the @progress_callback function
+ * @progress_user_data: (closure): data to pass to the @progress_callback function
  * @callback: a #GAsyncReadyCallback to call when authentication is finished
- * @user_data: data to pass to the @callback function
+ * @user_data: (closure): data to pass to the @callback function
  *
  * Queries the service to return a list of all albums belonging to the specified @username which match the given
  * @query. @self, @query and @username are all reffed/copied when this function is called, so can safely be unreffed/freed after
@@ -253,11 +260,11 @@ gdata_picasaweb_service_query_all_albums_async (GDataPicasaWebService *self, GDa
 /**
  * gdata_picasaweb_service_query_files:
  * @self: a #GDataPicasaWebService
- * @album: a #GDataPicasaWebAlbum from which to retrieve the files, or %NULL
- * @query: a #GDataQuery with the query parameters, or %NULL
+ * @album: (allow-none): a #GDataPicasaWebAlbum from which to retrieve the files, or %NULL
+ * @query: (allow-none): a #GDataQuery with the query parameters, or %NULL
  * @cancellable: optional #GCancellable object, or %NULL
- * @progress_callback: a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
- * @progress_user_data: data to pass to the @progress_callback function
+ * @progress_callback: (scope call): a #GDataQueryProgressCallback to call when an entry is loaded, or %NULL
+ * @progress_user_data: (closure): data to pass to the @progress_callback function
  * @error: a #GError, or %NULL
  *
  * Queries the specified @album for a list of the files which match the given @query. If @album is %NULL and a user is
@@ -265,7 +272,7 @@ gdata_picasaweb_service_query_all_albums_async (GDataPicasaWebService *self, GDa
  *
  * For more details, see gdata_service_query().
  *
- * Return value: a #GDataFeed of query results; unref with g_object_unref()
+ * Return value: (transfer full): a #GDataFeed of query results; unref with g_object_unref()
  *
  * Since: 0.4.0
  **/
@@ -349,7 +356,7 @@ parse_spliced_stream (GOutputStream *output_stream, GError **error)
 /**
  * gdata_picasaweb_service_upload_file:
  * @self: a #GDataPicasaWebService
- * @album: a #GDataPicasaWebAlbum into which to insert the file, or %NULL
+ * @album: (allow-none): a #GDataPicasaWebAlbum into which to insert the file, or %NULL
  * @file_entry: a #GDataPicasaWebFile to insert
  * @file_data: the actual file to upload
  * @cancellable: optional #GCancellable object, or %NULL
@@ -364,7 +371,7 @@ parse_spliced_stream (GOutputStream *output_stream, GError **error)
  * If there is a problem reading @file_data, an error from g_output_stream_splice() or g_file_query_info() will be returned. Other errors from
  * #GDataServiceError can be returned for other exceptional conditions, as determined by the server.
  *
- * Return value: the inserted #GDataPicasaWebFile with updated properties from @file_entry; unref with g_object_unref()
+ * Return value: (transfer full): the inserted #GDataPicasaWebFile with updated properties from @file_entry; unref with g_object_unref()
  *
  * Since: 0.4.0
  **/
@@ -443,7 +450,7 @@ gdata_picasaweb_service_upload_file (GDataPicasaWebService *self, GDataPicasaWeb
  * no user is authenticated with the service when trying to upload it,
  * %GDATA_SERVICE_ERROR_AUTHENTICATION_REQUIRED will be set.
  *
- * Return value: the inserted #GDataPicasaWebFile; unref with
+ * Return value: (transfer full): the inserted #GDataPicasaWebFile; unref with
  * g_object_unref()
  *
  * Since: 0.6.0
@@ -506,12 +513,12 @@ upload_file_async_cb (GOutputStream *output_stream, GAsyncResult *result, Upload
 /**
  * gdata_picasaweb_service_upload_file_async:
  * @self: a #GDataPicasaWebService
- * @album: a #GDataPicasaWebAlbum into which to insert the file, or %NULL
+ * @album: (allow-none): a #GDataPicasaWebAlbum into which to insert the file, or %NULL
  * @file_entry: a #GDataPicasaWebFile to insert
  * @file_data: the actual file to upload
  * @cancellable: optional #GCancellable object, or %NULL
  * @callback: a #GAsyncReadyCallback to call when authentication is finished
- * @user_data: data to pass to the @callback function
+ * @user_data: (closure): data to pass to the @callback function
  *
  * Uploads a file (photo or video) to the given PicasaWeb @album
  * asynchronously, using the @actual_file from disk and the metadata
@@ -594,7 +601,7 @@ gdata_picasaweb_service_upload_file_async (GDataPicasaWebService *self, GDataPic
  * Inserts a new album described by @album. A user must be
  * authenticated to use this function.
  *
- * Return value: the inserted #GDataPicasaWebAlbum; unref with
+ * Return value: (transfer full): the inserted #GDataPicasaWebAlbum; unref with
  * g_object_unref()
  *
  * Since: 0.6.0
