@@ -2,7 +2,7 @@
 /*
  * GData Client
  * Copyright (C) Richard Schwarting 2009 <aquarichy@gmail.com>
- * Copyright (C) Philip Withnall 2009 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2009–2010 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -647,7 +647,7 @@ test_photo (gconstpointer service)
 
 	gdata_picasaweb_file_get_edited (photo, &_time);
 	str = g_time_val_to_iso8601 (&_time);
-	g_assert_cmpstr (str, ==, "2009-10-17T08:52:18.885000Z");
+	g_assert_cmpstr (str, ==, "2010-05-13T20:45:13.603000Z");
 	g_free (str);
 
 	/* tests */
@@ -777,12 +777,13 @@ test_photo_feed_entry (gconstpointer service)
 	g_assert_cmpuint (g_list_length (files), ==, 1);
 
 	g_assert_cmpstr (gdata_entry_get_title (photo_entry), ==, "100_0269.jpg");
-	g_assert_cmpstr (gdata_entry_get_id (photo_entry), ==, "5328890138794566386");
+	g_assert_cmpstr (gdata_picasaweb_file_get_id (GDATA_PICASAWEB_FILE (photo_entry)), ==, "5328890138794566386");
+	g_assert_cmpstr (gdata_entry_get_id (photo_entry), ==, "http://picasaweb.google.com/data/entry/user/libgdata.picasaweb/albumid/5328889949261497249/photoid/5328890138794566386");
 	g_assert_cmpstr (gdata_entry_get_etag (photo_entry), !=, NULL);
 
 	gdata_entry_get_updated (photo_entry, &_time);
 	str = g_time_val_to_iso8601 (&_time);
-	g_assert_cmpstr (str, ==, "2009-10-17T08:52:18.885000Z");
+	g_assert_cmpstr (str, ==, "2010-05-13T20:45:13.603000Z");
 	g_free (str);
 
 	gdata_entry_get_published (photo_entry, &_time);
@@ -984,7 +985,8 @@ test_album_feed_entry (gconstpointer service)
 
 	/* Tests */
 	g_assert_cmpstr (gdata_entry_get_title (entry), ==, "Test Album 1 - Venice - Public");
-	g_assert_cmpstr (gdata_entry_get_id (entry), ==, "5328889949261497249");
+	g_assert_cmpstr (gdata_picasaweb_album_get_id (GDATA_PICASAWEB_ALBUM (entry)), ==, "5328889949261497249");
+	g_assert_cmpstr (gdata_entry_get_id (entry), ==, "http://picasaweb.google.com/data/entry/user/libgdata.picasaweb/albumid/5328889949261497249");
 	g_assert_cmpstr (gdata_entry_get_etag (entry), !=, NULL);
 	g_assert_cmpstr (gdata_entry_get_rights (entry), ==, "public");
 
@@ -1045,7 +1047,7 @@ test_insert_album (gconstpointer service)
 
 	error = NULL;
 
-	album = gdata_picasaweb_album_new ("album_id_72");
+	album = gdata_picasaweb_album_new (NULL);
 	g_assert (GDATA_IS_PICASAWEB_ALBUM (album));
 
 	gdata_entry_set_title (GDATA_ENTRY (album), "Thanksgiving photos");
@@ -1257,7 +1259,8 @@ test_album_new (gconstpointer service)
 				    "xmlns:app='http://www.w3.org/2007/app' "
 				    "xmlns:georss='http://www.georss.org/georss'>"
 					"<title type='text'></title>"
-					"<id>some-id</id>"
+					"<id>http://picasaweb.google.com/data/entry/user/libgdata.picasaweb/albumid/5328889949261497249</id>"
+					"<gphoto:id>5328889949261497249</gphoto:id>"
 					"<gphoto:access>private</gphoto:access>"
 					"<gphoto:timestamp>([0-9]+)</gphoto:timestamp>"
 					"<gphoto:commentingEnabled>false</gphoto:commentingEnabled>"
@@ -1265,7 +1268,8 @@ test_album_new (gconstpointer service)
 			     "</entry>", 0, 0, NULL);
 
 	/* Build the album */
-	album = gdata_picasaweb_album_new ("some-id");
+	album = gdata_picasaweb_album_new ("http://picasaweb.google.com/data/entry/user/libgdata.picasaweb/albumid/5328889949261497249");
+	g_assert (GDATA_IS_PICASAWEB_ALBUM (album));
 
 	/* Check the XML: match it against the regex built above, then check that the timestamp is within 100ms of the current time at the start of
 	 * the test function. We can't check it exactly, as a few milliseconds may have passed inbetween building the expected XML and building the XML
@@ -1283,6 +1287,31 @@ test_album_new (gconstpointer service)
 	g_object_unref (album);
 }
 
+static void
+test_query_etag (void)
+{
+	GDataPicasaWebQuery *query = gdata_picasaweb_query_new (NULL);
+
+	/* Test that setting any property will unset the ETag */
+	g_test_bug ("613529");
+
+#define CHECK_ETAG(C) \
+	gdata_query_set_etag (GDATA_QUERY (query), "foobar");		\
+	(C);								\
+	g_assert (gdata_query_get_etag (GDATA_QUERY (query)) == NULL);
+
+	CHECK_ETAG (gdata_picasaweb_query_set_visibility (query, GDATA_PICASAWEB_PUBLIC))
+	CHECK_ETAG (gdata_picasaweb_query_set_thumbnail_size (query, "500x430"))
+	CHECK_ETAG (gdata_picasaweb_query_set_image_size (query, "1024x768"))
+	CHECK_ETAG (gdata_picasaweb_query_set_tag (query, "tag"))
+	CHECK_ETAG (gdata_picasaweb_query_set_bounding_box (query, 0.0, 1.0, 20.0, 12.5))
+	CHECK_ETAG (gdata_picasaweb_query_set_location (query, "Somewhere near here"))
+
+#undef CHECK_ETAG
+
+	g_object_unref (query);
+}
+
 /* TODO: test private, public albums, test uploading */
 /* TODO: add queries to update albums, files on the server; test those */
 
@@ -1322,6 +1351,7 @@ main (int argc, char *argv[])
 	g_test_add_data_func ("/picasaweb/download/photo", service, test_download);
 	g_test_add_data_func ("/picasaweb/download/thumbnails", service, test_download_thumbnails);
 	g_test_add_data_func ("/picasaweb/album/new", service, test_album_new);
+	g_test_add_func ("/picasaweb/query/etag", test_query_etag);
 
 	retval = g_test_run ();
 	g_object_unref (service);
